import GHub from '@octokit/rest';
import { ICommit } from 'gitlog';
import { ILogger } from './utils/logger';
declare type Omit<T, K extends keyof T> = Pick<T, Exclude<keyof T, K>> & Partial<Pick<T, K>>;
export declare type IPRInfo = Omit<GHub.ReposCreateStatusParams, 'owner' | 'repo'>;
export interface IGitOptions {
    owner: string;
    repo: string;
    baseUrl?: string;
    token?: string;
}
export declare function getRandomColor(): string;
export default class Git {
    readonly options: IGitOptions;
    private readonly baseUrl;
    private readonly ghub;
    private readonly logger;
    constructor(options: IGitOptions, logger?: ILogger);
    getLatestReleaseInfo(): Promise<GHub.ReposGetLatestReleaseResponse>;
    getLatestRelease(): Promise<string>;
    getCommitDate(sha: string): Promise<string>;
    getFirstCommit(): Promise<string>;
    getSha(): Promise<string>;
    getLabels(prNumber: number): Promise<string[]>;
    getProjectLabels(): Promise<string[]>;
    getGitLog(start: string, end?: string): Promise<ICommit[]>;
    getUserByEmail(email: string): Promise<any>;
    getUserByUsername(username: string): Promise<GHub.UsersGetByUsernameResponse>;
    getPullRequest(pr: number): Promise<GHub.Response<GHub.PullsGetResponse>>;
    searchRepo(options: GHub.SearchIssuesAndPullRequestsParams): Promise<any>;
    createStatus(prInfo: IPRInfo): Promise<GHub.Response<GHub.ReposCreateStatusResponse>>;
    createLabel(label: string, name: string): Promise<GHub.Response<GHub.IssuesCreateLabelResponse>>;
    getProject(): Promise<GHub.ReposGetResponse>;
    getPullRequests(options?: Partial<GHub.PullsListParams>): Promise<GHub.PullsListResponseItem[]>;
    getCommitsForPR(pr: number): Promise<GHub.PullsListCommitsResponseItem[]>;
    createComment(message: string, pr: number, context?: string): Promise<GHub.Response<GHub.IssuesCreateCommentResponse>>;
    publish(releaseNotes: string, tag: string): Promise<GHub.Response<GHub.ReposCreateReleaseResponse>>;
}
export {};
